This is a framework that can make web applications in python, for example:
```
import Weban

app = Weban.Weban()

@app.route('/')
def home():
    return 'Welcome to Weban!'

@app.route('/about')
def about():
    return 'This is a simple web framework called Weban.'

if __name__ == '__main__':
    app.run()
```
Installation
```
pip install Weban
```
